<template>
    <div class="AIPage">
        <headline AITitle="收费统计"></headline>
        <div class="report-wrapper">
            <div class="unit">单位：元</div>
            <div class="flex-around title-wrapper">
                <div v-for="item in column" :key="item.key" class="title-item">
                    {{ item.name }}
                </div>
            </div>
            <div class="item-wrapper-outer">
                <div
                    class="empty-wrapper flex-center"
                    v-if="!tableData.length && !tableLoading"
                >
                    <el-empty
                        description="暂无数据"
                        :image-size="100"
                        :image="require('@/assets/img/bigScreen/empty1.png')"
                    ></el-empty>
                </div>
                <div
                    class="flex item-wrapper"
                    v-for="col in tableData"
                    :key="col.transDate"
                >
                    <div
                        v-for="(value, key) in col"
                        :key="key"
                        class="data-item"
                    >
                        {{ col[key] }}
                    </div>
                </div>
            </div>
        </div>
    </div>
</template>

<script>
import headline from './headlineAI.vue'
import report from '@/api/DataReport/Report.js'
import moment from 'moment'
export default {
    components: {headline},
    name: 'trafficReportAI',
    data() {
        return {
            tableLoading: false,
            column: [
                {
                    name: '日期',
                    key: 'transDate',
                },
                {
                    name: '出口',
                    key: 'exitusMoney',
                },
                {
                    name: '现金',
                    key: 'exitusCash',
                },
                {
                    name: '非现金',
                    key: 'exitusOnline',
                },
                {
                    name: 'ETC',
                    key: 'exitusEtc',
                },
                {
                    name: '非ETC',
                    key: 'exitusNoEtc',
                },
                {
                    name: '入口',
                    key: 'inletMoney',
                },
                {
                    name: '现金',
                    key: 'inletCash',
                },
                {
                    name: '非现金',
                    key: 'inletOnline',
                },
                {
                    name: 'ETC',
                    key: 'inletEtc',
                },
                {
                    name: '非ETC',
                    key: 'inletNoEtc',
                },
                {
                    name: '出入口',
                    key: 'allMoney',
                },
                {
                    name: '现金',
                    key: 'allCash',
                },
                {
                    name: '非现金',
                    key: 'allOnline',
                },
                {
                    name: 'ETC',
                    key: 'allEtc',
                },
                {
                    name: '非ETC',
                    key: 'allNoEtc',
                },
            ],
            tableData: [],
        }
    },
    mounted() {},
    activated() {
        this.getData()
    },
    methods: {
        getData() {
            this.tableLoading = true
            let startDate = moment()
                .startOf('month')
                .format('YYYY-MM-DD HH:mm:ss')
            let endDate = moment()
                .startOf('month')
                .subtract('month', -1)
                .format('YYYY-MM-DD HH:mm:ss')

            this.tollStationId = sessionStorage.getItem('tollStationId')
            this.params = {
                pageBean: {
                    page: 1,
                    pageSize: -1,
                    total: 0,
                },
                querys: [
                    {
                        group: 'main',
                        operation: 'LIKE',
                        parentGroup: '',
                        property: 'toll_station_id_',
                        relation: 'AND',
                        value: this.tollStationId,
                    },
                    {
                        group: 'main',
                        operation: 'BETWEEN',
                        parentGroup: '',
                        property: 'transDate',
                        relation: 'AND',
                        value: [startDate, endDate],
                    },
                ],
            }

            report
                .querytrafficCash(this.params)
                .then((res) => {
                    this.tableData = res.value || []
                })
                .finally(() => {
                    this.tableLoading = false
                })
        },
    },
}
</script>

<style scoped lang='scss'>
@import '../../views/BigScreen/bigScreen.scss';
.AIPage{
    width: 100%;
    height: 100%;
    overflow: hidden;
    position: relative;
    background: url('../../assets/img/bigScreen/bg.png') no-repeat center / 100% 100%;
}
.report-wrapper{
    width: calc(100% - 40px);
    height: calc(100% - 125px);
    color: #fff;
    background-color: rgba(79, 132, 212, 0.05);
    margin: 100px 20px 0 20px;
    box-sizing: border-box;
    border-radius: 10px;
    padding: 20px;
    position: relative;
}
.unit{
    color: #fff;
    font-size: 14px;
    font-weight: bold;
    position: absolute;
    left: 40px;
    top: -10px;
}
.item-wrapper-outer{
    width: 100%;
    height: calc(100% - 50px);
    overflow-y: auto;
}
.empty-wrapper{
    width: 100%;
    height: 100%;
}
.title-wrapper{
    gap: 10px;
}
.item-wrapper{
    gap: 10px;
    margin: 10px 0;
}
.title-item, .data-item{
    flex: 1;
    background-color:rgba(79, 132, 212, 0.2) ;
    padding: 10px;
    border-radius: 6px;
    color: #2187ff;
    text-align: center;
    font-size: 14px;
}
.title-item{
    font-weight: bold;
}
.data-item{
    color: #fff;
}
</style>